@@ -19,6 +19,9 @@ If you ask for data for a particular game that hasn't been cached to disk
 but is no longer being played, it will be automatically cached to disk
 so that no further downloads are required.
 
+nflgame requires Python 2.6 or Python 2.7. It does not (yet) work with
+Python 3.
+
 Examples
 ========
 
@@ -172,13 +175,16 @@ from an entire season::
     nflgame.combine(nflgame.games(2010)).csv('season2010.csv')
 """
 
-from collections import OrderedDict
+try:
+    from collections import OrderedDict
+except:
+    from ordereddict import OrderedDict  # from PyPI
 
 import nflgame.game as game
 import nflgame.player as player
 import nflgame.schedule as schedule
 
-VERSION = "1.0.4"
+VERSION = "1.0.6"
 
 NoPlayers = player.Players(None)
 """
