@@ -1,4 +1,3 @@
-from collections import OrderedDict
 import os
 import os.path as path
 import gzip
@@ -6,6 +5,7 @@ import json
 import sys
 import urllib2
 
+from nflgame import OrderedDict
 import nflgame.player as player
 
 _jsonf = path.join(path.split(__file__)[0], 'gamecenter-json', '%s.json.gz')
@@ -24,7 +24,7 @@ class Game (object):
         rawData = _get_json_data(eid)
         if rawData is None or rawData.strip() == '{}':
             return None
-        game = object.__new__(cls, eid)
+        game = object.__new__(cls)
         game.rawData = rawData
         return game
 
@@ -60,12 +60,19 @@ class Game (object):
             for team in ('home', 'away'):
                 score = self.data[team]['score'][str(q)]
                 self.__dict__['score_%s_q%d' % (team, q)] = int(score)
-        if self.score_home > self.score_away:
-            self.winner = self.home
-        elif self.score_away > self.score_home:
-            self.winner = self.away
+
+        if not self.game_over():
+            self.winner = None
         else:
-            self.winner = 'TIE'
+            if self.score_home > self.score_away:
+                self.winner = self.home
+                self.loser = self.away
+            elif self.score_away > self.score_home:
+                self.winner = self.away
+                self.loser = self.home
+            else:
+                self.winner = '%s/%s' % (self.home, self.away)
+                self.loser = '%s/%s' % (self.home, self.away)
 
         # Load the scoring summary into a simple list of strings.
         self.scores = []
